@@ -24,30 +24,42 @@
 # Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 #
 ##############################################################################
+from __future__ import print_function
 import zc.buildout
 from slapos.recipe.librecipe import wrap
 from slapos.recipe.librecipe import GenericSlapRecipe
+import six
 
 CONNECTION_PARAMETER_STRING = 'connection-'
 
 class Recipe(GenericSlapRecipe):
+  def __init__(self, buildout, name, options):
+    super(Recipe, self).__init__(buildout, name, options)
+    # Tell buildout about the sections we will access during install.
+    self._extend_set = done = set()
+    extends = [self.name]
+    while extends:
+      name = extends.pop()
+      done.add(name)
+      extends += set(self.buildout[name].get('-extends', '').split()) - done
+
   def _install(self):
-    publish_dict = dict()
-    options = self.options.copy()
-    del options['recipe']
-    slave_reference = options.pop('-slave-reference', None)
-    for k, v in options.iteritems():
-      if k[:1] == '-':
-        continue
-      publish_dict[k] = v
-    self._setConnectionDict(publish_dict, slave_reference)
+    publish_dict = {}
+    for name in self._extend_set:
+      section = self.buildout[name]
+      try:
+        publish = section['-publish'].split()
+      except KeyError:
+        publish = (k for k in section
+          if k != 'recipe' and not k.startswith('-'))
+      for k in publish:
+        publish_dict[k] = section[k]
+    self._setConnectionDict(publish_dict, self.options.get('-slave-reference'))
     return []
 
   def _setConnectionDict(self, publish_dict, slave_reference=None):
     return self.setConnectionDict(publish_dict, slave_reference)
 
-SERIALISED_MAGIC_KEY = '_'
-
 class Serialised(Recipe):
   def _setConnectionDict(self, publish_dict, slave_reference=None):
     return super(Serialised, self)._setConnectionDict(wrap(publish_dict), slave_reference)
@@ -67,9 +79,9 @@ class PublishSection(GenericSlapRecipe):
     for section in self.options['section-list'].strip().split():
       section = section.strip()
       options = self.buildout[section].copy()
-      for k, v in options.iteritems():
+      for k, v in six.iteritems(options):
         if k.startswith(CONNECTION_PARAMETER_STRING):
-          print k, v
+          print(k, v)
           publish_dict[k.lstrip(CONNECTION_PARAMETER_STRING)] = v
     self.setConnectionDict(publish_dict)
     return []
